@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
-our $DATE = '2015-09-27'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-01-14'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -274,7 +274,7 @@ sub gen_perinci_cmdline_completer_script {
 
             ($args{load_module} ? (
                 "# require extra modules\n",
-                (map {"require $_;\n"} @{$args{load_modules}}),
+                (map {"use $_ ();\n"} @{$args{load_module}}),
                 "\n") : ()),
 
             'my $args = ', dmp(\%args), ";\n\n",
@@ -450,7 +450,7 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.05 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-09-27.
+This document describes version 0.06 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2016-01-14.
 
 =head1 FUNCTIONS
 
@@ -459,6 +459,8 @@ This document describes version 0.05 of App::GenPericmdCompleterScript (from Per
 
 Generate Perinci::CmdLine completer script.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -577,7 +579,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
